//----------------------------------------------------------------------
//
//  RCS: $Id: axTime3.C,v 6.2 2005/10/19 18:25:36 arots Exp arots $
//
//  File:        axTime3.C
//  Programmer:  Arnold Rots  -  ASC
//  Date:        7 June 1999
//  Subsystem:   Utilities
//  Description: Time conversion utility using XTime.
//
// .NAME    axTime - Time conversion utility for AXAF
// .LIBRARY Util
// .HEADER  AXAF Time Converter
//
// .SECTION SYNOPSIS
//  .RI axTime3 time " " timeSystem(in) " " timeFormat(in) " " tS(out) " " tF(out)
//
// .SECTION Author
//  Arnold Rots,
//  USRA, ASC
//  <arots@xebec.gsfc.nasa.gov>
//
// .SECTION DESCRIPTION
//  axTime3 is a utility that performs conversions between different
//  time systems and formats.  A time is input on the command line in
//  any system and format, and may be retrieved in any system and format.
//  Optionally, a reference MJD may be specified, the default being
//  50814.0 TT (i.e., 1998.0 TT).
//
//  The supported time systems are: MET, TT, TAI, and UTC.  The codes are:
//  m[et], t[t], ta[i] or a, and u[tc].
//
//  The supported time formats are: seconds since 1994.0 in decimal
//  and hexadecimal format, Mission Day Number (ddd:hh:mm:ss.sss), Julian Day,
//  Modified Julian Day (=JD-2400000.5), Date (yyyy:ddd:hh:mm:ss.ss...),
//  Calendar Date (yyyyMondd at hh:mm:ss.ss...), and FITS-style date-time
//  string (yyyy-mm-ddThh:mm:ss.ss...).  The last three format codes may have
//  a digit appended to indicate the number of decimals requested in the
//  seconds field.
//  The codes are: s, h, n, j, d[n], c[n], and f[n].
//
//  The user is expected to provide the time to be converted on the command
//  line, with a time system and a time format specification for both input
//  and output.
//
//  Time system and time format codes may be abbreviated to single
//  characters and are case-insensitive.
//
//  A reference MJD may optionally be inserted between the specifications
//  of the input and output time system and time format, either as a single
//  number, or as an integer and fractional part (long and double).
//
// .VERSION $Revision $
//----------------------------------------------------------------------
//

#include <string.h>
#include <iostream>
#include "XTime.h"

int main (int argc, char const *argv[]) {

  char progName[256] ;
  char time_out[256];

  //    Program name
  strcpy (progName, argv[0]) ;

  int error = axTime3( argc, argv, time_out );

  if ( error )
      std::cerr << progName << ": " << time_out << "\n" ;

  else
      std::cout << time_out;

  return error ;
}
